@@ -18,5 +18,11 @@ is.POSIXlt <- function(x) is(x, "POSIXlt")
 is.POSIXct <- function(x) is(x, "POSIXct")
 
 #' @S3method c POSIXct
-c.POSIXct <- function (..., recursive = FALSE) 
-	.POSIXct(c(unlist(lapply(list(...), unclass))), tz = tz(list(...)[[1]]))
\ No newline at end of file
+c.POSIXct <- function (..., recursive = FALSE) {
+	.POSIXct(c(unlist(lapply(list(...), unclass))), tz = tz(list(...)[[1]]))
+}
+
+#' @S3method c POSIXlt
+c.POSIXlt <- function (..., recursive = FALSE) {
+  as.POSIXlt(do.call("c.POSIXct", lapply(list(...), as.POSIXct)))
+}
