@@ -3,12 +3,13 @@ NULL
 
 #' Get/set seconds component of a date-time.
 #'
-#' Date-time must be a  POSIXct, POSIXlt, Date, chron, yearmon, yearqtr, zoo, 
+#' Date-time must be a  POSIXct, POSIXlt, Date, Period, chron, yearmon, yearqtr, zoo, 
 #' zooreg, timeDate, xts, its, ti, jul, timeSeries, and fts objects. 
 #'
 #' @export second "second<-"
 #' @aliases second second<-
 #' @S3method second default
+#' @S3method second Period
 #' @param x a date-time object   
 #' @return the seconds element of x as a decimal number
 #' @keywords utilities manip chron methods
@@ -24,6 +25,17 @@ second <- function(x)
 second.default <- function(x)
   as.POSIXlt(x, tz = tz(x))$sec
 
+second.Period <- function(x)
+  slot(x, ".Data")
+
 "second<-" <- function(x, value)
   x <- x + seconds(value - second(x))
   
+
+setGeneric("second<-")
+
+#' @export
+setMethod("second<-", signature("Period"), function(x, value){
+  slot(x, ".Data") <- value
+  x
+})
